##R code to run the Bayesian Poisson GLM for proportion of juveniles, adapted from Kry 2010
##This analysis requires JAGS
##Required R packages
library(jagsUI) 


#####################
#########DATA########
#####################

#Loading data
data<-read.table("brief_bd_darwinii.txt", header=T)

#Proportion of infected as prevalence (%)
data$prev<-data$prev*100


############################################################################
# Specify model in BUGS language
############################################################################
sink("binomial.jags")
cat("
    model {
# Priors

alpha ~ dnorm(0, 0.01) # Intercept
beta ~ dnorm(0, 0.01) # Slope


# Likelihood
for (i in 1:n) {
  C[i] ~ dbin(p[i], N[i])
  logit(p[i]) <- alpha + beta*prevalence[i]

  
  # Fit assessments: Pearson residuals and posterior predictive check
  Presi[i] <- (C[i]-N[i]*p[i]) / sqrt(N[i]*p[i]*(1-p[i])) # Pearson resi
  C.new[i] ~ dbin(p[i], N[i]) # Create replicate data set
  Presi.new[i] <- (C.new[i]-N[i]*p[i]) / sqrt(N[i]*p[i]*(1-p[i]))
  D[i] <- pow(Presi[i], 2) # Squared Pearson residuals
  D.new[i] <- pow(Presi.new[i], 2)
}#i
  
  # Add up discrepancy measures
  fit <- sum(D[])
  fit.new <- sum(D.new[])
  
} 

    ",fill = TRUE) 
sink() # End Model



# bundle data 
jags.data <- list(C = data$juv, N = data$N, prevalence = data$prev, n = length (data$N)) 


# Inits function
inits <- function() {list(
  alpha = rnorm(1,1,1),
  beta = rnorm(1,1,1)) 
} 


# Parameters monitored 
parameters <-  c("alpha", "beta")



# MCMC settings 
ni = 100000
nt = 1
nb= 10000
nc <- 3 

# Call JAGS from R 

binom_1<- jags(jags.data, inits, parameters,parallel=T, "binomial.jags", n.chains = nc, n.thin = nt, n.iter = ni, n.burnin = nb) 
binom_1



##Predict relationship and plot
par(mfrow = c(1,2))

new.prev<-seq(from=0,to=15,length.out = 100)

lin.pred <- binom_1$mean$alpha + binom_1$mean$beta * new.prev
lin.pred.low<-binom_1$q2.5$alpha + binom_1$q2.5$beta * new.prev
lin.pred.high<-binom_1$q97.5$alpha + binom_1$q97.5$beta * new.prev


plot(new.prev, exp(lin.pred) / (1 + exp(lin.pred)), ylim=c(0,1), type =
       "l", lwd= 2, col = "blue", ylab = "Proportion of juveniles",xlab="Prevalence")
points(data$prev,data$prop_juv)
lines(new.prev,exp(lin.pred.low) / (1 + exp(lin.pred.low)))
lines(new.prev,exp(lin.pred.high) / (1 + exp(lin.pred.high)))

hist(binom_1$sims.list$beta,freq=F,xlab="Beta")




  